{% extends 'infra_optim/base.html' %}
{% load i18n %}
{% block title %}{% trans workflow.name %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=workflow.name %}
{% endblock page_header %}

{% block main %}
  {% include 'infra_optim/_fullscreen_workflow.html' %}
{% endblock %}
